@@ -17,7 +17,7 @@ use IO::File;
 use vars qw($VERSION @ISA);
 
 # The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 1.105 $, 10;
+$VERSION = "2.111";
 
 # Inheritance:
 @ISA = qw(IO::File);
@@ -43,7 +43,7 @@ sub new {
 # Destructor.
 #
 sub DESTROY {
-    shift->close(1);   # like close, but raises fatal exception on failure
+    shift->close(1);   ### like close, but raises fatal exception on failure
 }
 
 #------------------------------
@@ -53,14 +53,14 @@ sub DESTROY {
 #
 sub open {
     my ($self, $path, $mode) = @_;
-    ref($self) or $self = $self->new;    # now we have an instance! 
+    ref($self) or $self = $self->new;    ### now we have an instance! 
 
-    # Create tmp path, and remember this info: 
+    ### Create tmp path, and remember this info: 
     my $temp = "${path}..TMP" . ${*$self}{'io_atomicfile_suffix'};
     ${*$self}{'io_atomicfile_temp'} = $temp;
     ${*$self}{'io_atomicfile_path'} = $path;
 
-    # Open the file!  Returns filehandle on success, for use as a constructor: 
+    ### Open the file!  Returns filehandle on success, for use as a constructor: 
     $self->SUPER::open($temp, $mode) ? $self : undef;
 }
 
@@ -85,11 +85,14 @@ sub _closed {
 #
 sub close {
     my ($self, $die) = @_;
-    unless ($self->_closed(1)) {             # sentinel...
-        $self->SUPER::close();    
-        rename(${*$self}{'io_atomicfile_temp'},
-	       ${*$self}{'io_atomicfile_path'}) 
-            or ($die ? die "close atomic file: $!\n" : return undef); 
+    unless ($self->_closed(1)) {             ### sentinel...
+	    if ($self->SUPER::close()) {
+		    rename(${*$self}{'io_atomicfile_temp'},
+			   ${*$self}{'io_atomicfile_path'})
+			or ($die ? die "close (rename) atomic file: $!\n" : return undef);
+	    } else {
+		    ($die ? die "close atomic file: $!\n" : return undef);
+	    }
     }
     1;
 }
@@ -102,7 +105,7 @@ sub close {
 #
 sub delete {
     my $self = shift;
-    unless ($self->_closed(1)) {             # sentinel...
+    unless ($self->_closed(1)) {             ### sentinel...
         $self->SUPER::close();    
         return unlink(${*$self}{'io_atomicfile_temp'});
     }
@@ -134,18 +137,18 @@ IO::AtomicFile - write a file which is updated atomically
 =head1 SYNOPSIS
 
     use IO::AtomicFile;
-    
-    # Write a temp file, and have it install itself when closed:
+
+    ### Write a temp file, and have it install itself when closed:
     my $FH = IO::AtomicFile->open("bar.dat", "w");
     print $FH "Hello!\n";
     $FH->close || die "couldn't install atomic file: $!";    
-    
-    # Write a temp file, but delete it before it gets installed:
+
+    ### Write a temp file, but delete it before it gets installed:
     my $FH = IO::AtomicFile->open("bar.dat", "w");
     print $FH "Hello!\n";
     $FH->delete; 
-   
-    # Write a temp file, but neither install it nor delete it:
+
+    ### Write a temp file, but neither install it nor delete it:
     my $FH = IO::AtomicFile->open("bar.dat", "w");
     print $FH "Hello!\n";
     $FH->detach;   
@@ -174,17 +177,23 @@ done by the destructor will raise a fatal exception if the rename()
 fails.  The explicit close() just returns undef.   
 
 You can also decide at any point to trash the file you've been 
-building. 
+building.
 
 
 =head1 AUTHOR
 
+=head2 Primary Maintainer
+
+Dianne Skoll (F<dfs@roaringpenguin.com>).
+
+=head2 Original Author
+
 Eryq (F<eryq@zeegee.com>).
 President, ZeeGee Software Inc (F<http://www.zeegee.com>).
 
 
 =head1 REVISION
 
-$Revision: 1.105 $
+$Revision: 1.2 $
 
 =cut 
