@@ -12,7 +12,7 @@ use Exporter;
 # Inheritance, exporting, and package version:
 @ISA     = qw(Exporter);
 @EXPORT  = qw(wraptie);
-$VERSION = substr q$Revision: 2.101 $, 10;
+$VERSION = "2.111";
 
 # Function, exported.
 sub wraptie {
@@ -471,8 +471,19 @@ I have not explored all the ramifications of this use of tie().
 I<Here there be dragons>.
 
 
+=head1 VERSION
+
+$Id: WrapTie.pm,v 1.2 2005/02/10 21:21:53 dfs Exp $
+
+
 =head1 AUTHOR
 
+=item Primary Maintainer
+
+Dianne Skoll (F<dfs@roaringpenguin.com>).
+
+=item Original Author
+
 Eryq (F<eryq@zeegee.com>).
 President, ZeeGee Software Inc (F<http://www.zeegee.com>).
 
